@@ -24,6 +24,7 @@
 #include <KConfig>
 #include <QFile>
 #include <QRegularExpression>
+#include <QPointer>
 
 using namespace MailImporter;
 
@@ -46,6 +47,31 @@ FilterThunderbird::~FilterThunderbird()
 {
 }
 
+QString FilterThunderbird::isMailerFound()
+{
+    QDir directory(FilterThunderbird::defaultSettingsPath());
+    if (directory.exists()) {
+        QString currentProfile;
+        const QMap<QString, QString> listOfPath = FilterThunderbird::listProfile(currentProfile, FilterThunderbird::defaultSettingsPath());
+        bool foundMailConfigurated = false;
+        QMap<QString, QString>::const_iterator i = listOfPath.constBegin();
+        while (i != listOfPath.constEnd()) {
+            QDir dir(FilterThunderbird::defaultSettingsPath() + QLatin1Char('/') + i.value());
+            if (!dir.entryList(QStringList({QStringLiteral("ImapMail"), QStringLiteral("Mail")}), QDir::Dirs).isEmpty()) {
+                foundMailConfigurated = true;
+                break;
+            }
+            ++i;
+        }
+        if (foundMailConfigurated) {
+            return i18nc("name of thunderbird application", "Thunderbird");
+        } else {
+            return {};
+        }
+    }
+    return {};
+}
+
 QString FilterThunderbird::defaultSettingsPath()
 {
     return QDir::homePath() + QLatin1String("/.thunderbird/");
@@ -60,11 +86,14 @@ QString FilterThunderbird::defaultProfile(const QString &defaultSettingPath, QWi
     } else if (listProfile.count() == 1) {
         return currentProfile;
     } else {
-        SelectThunderbirdProfileDialog dialog(parent);
-        dialog.fillProfile(listProfile, currentProfile);
-        if (dialog.exec()) {
-            return dialog.selectedProfile();
+        QPointer<SelectThunderbirdProfileDialog> dialog = new SelectThunderbirdProfileDialog(parent);
+        dialog->fillProfile(listProfile, currentProfile);
+        if (dialog->exec()) {
+            currentProfile = dialog->selectedProfile();
+            delete dialog;
+            return currentProfile;
         }
+        delete dialog;
     }
     return currentProfile;
 }
@@ -265,14 +294,14 @@ void FilterThunderbird::importMBox(const QString &mboxName, const QString &rootD
         if (mboxName.length() > 20) {
             QString tmp_info = mboxName;
             tmp_info = tmp_info.replace(mailDir(), QStringLiteral("../"));
-            if (tmp_info.contains(QStringLiteral(".sbd"))) {
+            if (tmp_info.contains(QLatin1String(".sbd"))) {
                 tmp_info.remove(QStringLiteral(".sbd"));
             }
             filterInfo()->setFrom(tmp_info);
         } else {
             filterInfo()->setFrom(mboxName);
         }
-        if (targetDir.contains(QStringLiteral(".sbd"))) {
+        if (targetDir.contains(QLatin1String(".sbd"))) {
             QString tmp_info = targetDir;
             tmp_info.remove(QStringLiteral(".sbd"));
             filterInfo()->setTo(tmp_info);
@@ -311,13 +340,13 @@ void FilterThunderbird::importMBox(const QString &mboxName, const QString &rootD
             QString destFolder;
             QString _targetDir = targetDir;
             if (!targetDir.isNull()) {
-                if (_targetDir.contains(QStringLiteral(".sbd"))) {
+                if (_targetDir.contains(QLatin1String(".sbd"))) {
                     _targetDir.remove(QStringLiteral(".sbd"));
                 }
                 destFolder += defaultInstallFolder() + _targetDir + QLatin1Char('/') + filenameInfo.completeBaseName();// mboxName;
             } else {
                 destFolder = defaultInstallFolder() + rootDir;
-                if (destFolder.contains(QStringLiteral(".sbd"))) {
+                if (destFolder.contains(QLatin1String(".sbd"))) {
                     destFolder.remove(QStringLiteral(".sbd"));
                 }
             }
